==> zio-aws-iotwireless_2.13-5.17.265.1-sources.jar: zio/aws/iotwireless/model/GetNetworkAnalyzerConfigurationResponse.scala <==
package zio.aws.iotwireless.model
import zio.aws.iotwireless.model.primitives.{
  WirelessGatewayId,
  NetworkAnalyzerConfigurationName,
  Description,
  WirelessDeviceId,
  NetworkAnalyzerConfigurationArn
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetNetworkAnalyzerConfigurationResponse(
    traceContent: Optional[zio.aws.iotwireless.model.TraceContent] =
      Optional.Absent,
    wirelessDevices: Optional[Iterable[WirelessDeviceId]] = Optional.Absent,
    wirelessGateways: Optional[Iterable[WirelessGatewayId]] = Optional.Absent,
    description: Optional[Description] = Optional.Absent,
    arn: Optional[NetworkAnalyzerConfigurationArn] = Optional.Absent,
    name: Optional[NetworkAnalyzerConfigurationName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse = {
    import GetNetworkAnalyzerConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
      .builder()
      .optionallyWith(traceContent.map(value => value.buildAwsValue()))(
        _.traceContent
      )
      .optionallyWith(
        wirelessDevices.map(value =>
          value.map { item =>
            WirelessDeviceId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessDevices)
      .optionallyWith(
        wirelessGateways.map(value =>
          value.map { item =>
            WirelessGatewayId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessGateways)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        arn.map(value =>
          NetworkAnalyzerConfigurationArn.unwrap(value): java.lang.String
        )
      )(_.arn)
      .optionallyWith(
        name.map(value =>
          NetworkAnalyzerConfigurationName.unwrap(value): java.lang.String
        )
      )(_.name)
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse.ReadOnly =
    zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
      .wrap(buildAwsValue())
}
object GetNetworkAnalyzerConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse =
      zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse(
        traceContent.map(value => value.asEditable),
        wirelessDevices.map(value => value),
        wirelessGateways.map(value => value),
        description.map(value => value),
        arn.map(value => value),
        name.map(value => value)
      )
    def traceContent: Optional[zio.aws.iotwireless.model.TraceContent.ReadOnly]
    def wirelessDevices: Optional[List[WirelessDeviceId]]
    def wirelessGateways: Optional[List[WirelessGatewayId]]
    def description: Optional[Description]
    def arn: Optional[NetworkAnalyzerConfigurationArn]
    def name: Optional[NetworkAnalyzerConfigurationName]
    def getTraceContent
        : ZIO[Any, AwsError, zio.aws.iotwireless.model.TraceContent.ReadOnly] =
      AwsError.unwrapOptionField("traceContent", traceContent)
    def getWirelessDevices: ZIO[Any, AwsError, List[WirelessDeviceId]] =
      AwsError.unwrapOptionField("wirelessDevices", wirelessDevices)
    def getWirelessGateways: ZIO[Any, AwsError, List[WirelessGatewayId]] =
      AwsError.unwrapOptionField("wirelessGateways", wirelessGateways)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getArn: ZIO[Any, AwsError, NetworkAnalyzerConfigurationArn] =
      AwsError.unwrapOptionField("arn", arn)
    def getName: ZIO[Any, AwsError, NetworkAnalyzerConfigurationName] =
      AwsError.unwrapOptionField("name", name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
  ) extends zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse.ReadOnly {
    override val traceContent
        : Optional[zio.aws.iotwireless.model.TraceContent.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.traceContent())
        .map(value => zio.aws.iotwireless.model.TraceContent.wrap(value))
    override val wirelessDevices: Optional[List[WirelessDeviceId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessDevices())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessDeviceId(item)
          }.toList
        )
    override val wirelessGateways: Optional[List[WirelessGatewayId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessGateways())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessGatewayId(item)
          }.toList
        )
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iotwireless.model.primitives.Description(value))
    override val arn: Optional[NetworkAnalyzerConfigurationArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.arn())
        .map(value =>
          zio.aws.iotwireless.model.primitives
            .NetworkAnalyzerConfigurationArn(value)
        )
    override val name: Optional[NetworkAnalyzerConfigurationName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.name())
        .map(value =>
          zio.aws.iotwireless.model.primitives
            .NetworkAnalyzerConfigurationName(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
  ): zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotwireless_2.13-6.20.83.1-sources.jar: zio/aws/iotwireless/model/GetNetworkAnalyzerConfigurationResponse.scala <==
package zio.aws.iotwireless.model
import zio.aws.iotwireless.model.primitives.{
  WirelessGatewayId,
  NetworkAnalyzerConfigurationName,
  MulticastGroupId,
  Description,
  WirelessDeviceId,
  NetworkAnalyzerConfigurationArn
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetNetworkAnalyzerConfigurationResponse(
    traceContent: Optional[zio.aws.iotwireless.model.TraceContent] =
      Optional.Absent,
    wirelessDevices: Optional[Iterable[WirelessDeviceId]] = Optional.Absent,
    wirelessGateways: Optional[Iterable[WirelessGatewayId]] = Optional.Absent,
    description: Optional[Description] = Optional.Absent,
    arn: Optional[NetworkAnalyzerConfigurationArn] = Optional.Absent,
    name: Optional[NetworkAnalyzerConfigurationName] = Optional.Absent,
    multicastGroups: Optional[Iterable[MulticastGroupId]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse = {
    import GetNetworkAnalyzerConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
      .builder()
      .optionallyWith(traceContent.map(value => value.buildAwsValue()))(
        _.traceContent
      )
      .optionallyWith(
        wirelessDevices.map(value =>
          value.map { item =>
            WirelessDeviceId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessDevices)
      .optionallyWith(
        wirelessGateways.map(value =>
          value.map { item =>
            WirelessGatewayId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessGateways)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        arn.map(value =>
          NetworkAnalyzerConfigurationArn.unwrap(value): java.lang.String
        )
      )(_.arn)
      .optionallyWith(
        name.map(value =>
          NetworkAnalyzerConfigurationName.unwrap(value): java.lang.String
        )
      )(_.name)
      .optionallyWith(
        multicastGroups.map(value =>
          value.map { item =>
            MulticastGroupId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.multicastGroups)
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse.ReadOnly =
    zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
      .wrap(buildAwsValue())
}
object GetNetworkAnalyzerConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse =
      zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse(
        traceContent.map(value => value.asEditable),
        wirelessDevices.map(value => value),
        wirelessGateways.map(value => value),
        description.map(value => value),
        arn.map(value => value),
        name.map(value => value),
        multicastGroups.map(value => value)
      )
    def traceContent: Optional[zio.aws.iotwireless.model.TraceContent.ReadOnly]
    def wirelessDevices: Optional[List[WirelessDeviceId]]
    def wirelessGateways: Optional[List[WirelessGatewayId]]
    def description: Optional[Description]
    def arn: Optional[NetworkAnalyzerConfigurationArn]
    def name: Optional[NetworkAnalyzerConfigurationName]
    def multicastGroups: Optional[List[MulticastGroupId]]
    def getTraceContent
        : ZIO[Any, AwsError, zio.aws.iotwireless.model.TraceContent.ReadOnly] =
      AwsError.unwrapOptionField("traceContent", traceContent)
    def getWirelessDevices: ZIO[Any, AwsError, List[WirelessDeviceId]] =
      AwsError.unwrapOptionField("wirelessDevices", wirelessDevices)
    def getWirelessGateways: ZIO[Any, AwsError, List[WirelessGatewayId]] =
      AwsError.unwrapOptionField("wirelessGateways", wirelessGateways)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getArn: ZIO[Any, AwsError, NetworkAnalyzerConfigurationArn] =
      AwsError.unwrapOptionField("arn", arn)
    def getName: ZIO[Any, AwsError, NetworkAnalyzerConfigurationName] =
      AwsError.unwrapOptionField("name", name)
    def getMulticastGroups: ZIO[Any, AwsError, List[MulticastGroupId]] =
      AwsError.unwrapOptionField("multicastGroups", multicastGroups)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
  ) extends zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse.ReadOnly {
    override val traceContent
        : Optional[zio.aws.iotwireless.model.TraceContent.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.traceContent())
        .map(value => zio.aws.iotwireless.model.TraceContent.wrap(value))
    override val wirelessDevices: Optional[List[WirelessDeviceId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessDevices())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessDeviceId(item)
          }.toList
        )
    override val wirelessGateways: Optional[List[WirelessGatewayId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessGateways())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessGatewayId(item)
          }.toList
        )
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iotwireless.model.primitives.Description(value))
    override val arn: Optional[NetworkAnalyzerConfigurationArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.arn())
        .map(value =>
          zio.aws.iotwireless.model.primitives
            .NetworkAnalyzerConfigurationArn(value)
        )
    override val name: Optional[NetworkAnalyzerConfigurationName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.name())
        .map(value =>
          zio.aws.iotwireless.model.primitives
            .NetworkAnalyzerConfigurationName(value)
        )
    override val multicastGroups: Optional[List[MulticastGroupId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.multicastGroups())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.MulticastGroupId(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.GetNetworkAnalyzerConfigurationResponse
  ): zio.aws.iotwireless.model.GetNetworkAnalyzerConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}
